==> commands-1.5.4-sources.jar: org/jclouds/karaf/chef/commands/completer/ChefContextNameCompleter.java <==
/**
 * Licensed to jclouds, Inc. (jclouds) under one or more
 * contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  jclouds licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.jclouds.karaf.chef.commands.completer;

import org.apache.karaf.shell.console.Completer;
import org.apache.karaf.shell.console.completer.StringsCompleter;
import org.jclouds.chef.ChefService;

import java.util.List;

public class ChefContextNameCompleter implements Completer {

    private final StringsCompleter delegate = new StringsCompleter();
    private List<? extends ChefService> chefServices;

    @Override
    public int complete(String buffer, int cursor, List<String> candidates) {
        try {
            if (chefServices != null) {
                for (ChefService chefService : chefServices) {
                    String id = (String) chefService.getContext().getName();
                    if (id != null) {
                        delegate.getStrings().add(id);
                    }
                }
            }
        } catch (Exception ex) {
            // noop
        }
        return delegate.complete(buffer, cursor, candidates);
    }

    public List<? extends ChefService> getChefServices() {
        return chefServices;
    }

    public void setChefServices(List<? extends ChefService> chefServices) {
        this.chefServices = chefServices;
    }
}

==> commands-1.6.0-sources.jar: org/jclouds/karaf/chef/commands/completer/ChefContextNameCompleter.java <==
/**
 * Licensed to jclouds, Inc. (jclouds) under one or more
 * contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  jclouds licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.jclouds.karaf.chef.commands.completer;

import org.apache.karaf.shell.console.Completer;
import org.apache.karaf.shell.console.completer.StringsCompleter;
import org.jclouds.chef.ChefService;

import java.util.List;

public class ChefContextNameCompleter implements Completer {

    private final StringsCompleter delegate = new StringsCompleter();
    private List<? extends ChefService> chefServices;

    @Override
    public int complete(String buffer, int cursor, List<String> candidates) {
        try {
            if (chefServices != null) {
                for (ChefService chefService : chefServices) {
                    String name = (String) chefService.getContext().unwrap().getName();
                    if (name != null) {
                        delegate.getStrings().add(name);
                    }
                }
            }
        } catch (Exception ex) {
            // noop
        }
        return delegate.complete(buffer, cursor, candidates);
    }

    public List<? extends ChefService> getChefServices() {
        return chefServices;
    }

    public void setChefServices(List<? extends ChefService> chefServices) {
        this.chefServices = chefServices;
    }
}
